@@ -16,7 +16,7 @@ use crate::byte_chunk::{ByteChunk, Chunk};
 /// Runs in O(N) time.
 #[inline]
 pub fn count_breaks(text: &str) -> usize {
-    count_breaks_internal::<Chunk>(text.as_bytes())
+    count_breaks_impl::<Chunk>(text.as_bytes())
 }
 
 /// Converts from byte-index to line-index in a string slice.
@@ -32,7 +32,7 @@ pub fn count_breaks(text: &str) -> usize {
 #[inline]
 pub fn from_byte_idx(text: &str, byte_idx: usize) -> usize {
     let i = byte_idx.min(text.len());
-    let nl_count = count_breaks_internal::<Chunk>(&text.as_bytes()[..i]);
+    let nl_count = count_breaks_impl::<Chunk>(&text.as_bytes()[..i]);
     if crate::is_not_crlf_middle(i, text.as_bytes()) {
         nl_count
     } else {
@@ -51,13 +51,13 @@ pub fn from_byte_idx(text: &str, byte_idx: usize) -> usize {
 /// Runs in O(N) time.
 #[inline]
 pub fn to_byte_idx(text: &str, line_idx: usize) -> usize {
-    to_byte_idx_inner::<Chunk>(text.as_bytes(), line_idx)
+    to_byte_idx_impl::<Chunk>(text.as_bytes(), line_idx)
 }
 
 //-------------------------------------------------------------
 
 #[inline(always)]
-fn to_byte_idx_inner<T: ByteChunk>(text: &[u8], line_idx: usize) -> usize {
+fn to_byte_idx_impl<T: ByteChunk>(text: &[u8], line_idx: usize) -> usize {
     // Get `middle` so we can do more efficient chunk-based counting.
     // We can't use this to get `end`, however, because the start index of
     // `end` actually depends on the accumulating line counts during the
@@ -149,7 +149,7 @@ fn to_byte_idx_inner<T: ByteChunk>(text: &[u8], line_idx: usize) -> usize {
 /// The following unicode sequences are considered newlines by this function:
 /// - u{000A}        (Line Feed)
 #[inline(always)]
-fn count_breaks_internal<T: ByteChunk>(text: &[u8]) -> usize {
+fn count_breaks_impl<T: ByteChunk>(text: &[u8]) -> usize {
     // Get `middle` so we can do more efficient chunk-based counting.
     let (start, middle, end) = unsafe { text.align_to::<T>() };
 
