@@ -13,7 +13,7 @@ use crate::byte_chunk::{ByteChunk, Chunk};
 /// Runs in O(N) time.
 #[inline]
 pub fn count_breaks(text: &str) -> usize {
-    count_breaks_internal::<Chunk>(text.as_bytes())
+    count_breaks_impl::<Chunk>(text.as_bytes())
 }
 
 /// Converts from byte-index to line-index in a string slice.
@@ -29,7 +29,7 @@ pub fn count_breaks(text: &str) -> usize {
 #[inline]
 pub fn from_byte_idx(text: &str, byte_idx: usize) -> usize {
     let i = byte_idx.min(text.len());
-    count_breaks_internal::<Chunk>(&text.as_bytes()[..i])
+    count_breaks_impl::<Chunk>(&text.as_bytes()[..i])
 }
 
 /// Converts from line-index to byte-index in a string slice.
@@ -43,13 +43,13 @@ pub fn from_byte_idx(text: &str, byte_idx: usize) -> usize {
 /// Runs in O(N) time.
 #[inline]
 pub fn to_byte_idx(text: &str, line_idx: usize) -> usize {
-    to_byte_idx_inner::<Chunk>(text.as_bytes(), line_idx)
+    to_byte_idx_impl::<Chunk>(text.as_bytes(), line_idx)
 }
 
 //-------------------------------------------------------------
 
 #[inline(always)]
-fn to_byte_idx_inner<T: ByteChunk>(text: &[u8], line_idx: usize) -> usize {
+fn to_byte_idx_impl<T: ByteChunk>(text: &[u8], line_idx: usize) -> usize {
     // Get `middle` so we can do more efficient chunk-based counting.
     // We can't use this to get `end`, however, because the start index of
     // `end` actually depends on the accumulating line counts during the
@@ -118,32 +118,38 @@ fn to_byte_idx_inner<T: ByteChunk>(text: &[u8], line_idx: usize) -> usize {
 /// The following unicode sequences are considered newlines by this function:
 /// - u{000A}        (Line Feed)
 #[inline(always)]
-fn count_breaks_internal<T: ByteChunk>(text: &[u8]) -> usize {
-    // Get `middle` so we can do more efficient chunk-based counting.
-    let (start, middle, end) = unsafe { text.align_to::<T>() };
+fn count_breaks_impl<T: ByteChunk>(text: &[u8]) -> usize {
+    if text.len() < T::SIZE {
+        // Bypass the more complex routine for short strings, where the
+        // complexity hurts performance.
+        text.iter().map(|byte| (*byte == 0x0A) as usize).sum()
+    } else {
+        // Get `middle` so we can do more efficient chunk-based counting.
+        let (start, middle, end) = unsafe { text.align_to::<T>() };
 
-    let mut count = 0;
+        let mut count = 0;
 
-    // Take care of unaligned bytes at the beginning.
-    for byte in start.iter() {
-        count += (*byte == 0x0A) as usize;
-    }
-
-    // Take care of the middle bytes in big chunks.
-    for chunks in middle.chunks(T::MAX_ACC) {
-        let mut acc = T::zero();
-        for chunk in chunks.iter() {
-            acc = acc.add(chunk.cmp_eq_byte(0x0A));
+        // Take care of unaligned bytes at the beginning.
+        for byte in start.iter() {
+            count += (*byte == 0x0A) as usize;
         }
-        count += acc.sum_bytes();
-    }
 
-    // Take care of unaligned bytes at the end.
-    for byte in end.iter() {
-        count += (*byte == 0x0A) as usize;
-    }
+        // Take care of the middle bytes in big chunks.
+        for chunks in middle.chunks(T::MAX_ACC) {
+            let mut acc = T::zero();
+            for chunk in chunks.iter() {
+                acc = acc.add(chunk.cmp_eq_byte(0x0A));
+            }
+            count += acc.sum_bytes();
+        }
 
-    count
+        // Take care of unaligned bytes at the end.
+        for byte in end.iter() {
+            count += (*byte == 0x0A) as usize;
+        }
+
+        count
+    }
 }
 
 //=============================================================
